@@ -1,6 +1,5 @@
 from learning_loop_node.context import Context
 import logging
-import aiohttp
 from .status import Status, State
 from fastapi import FastAPI
 import socketio
@@ -10,22 +9,24 @@ import os
 from icecream import ic
 from .loop import loop
 from aiohttp.client_exceptions import ClientConnectorError
+from fastapi_utils.tasks import repeat_every
 import logging
+from uuid import uuid4
 
 
 class Node(FastAPI):
     name: str
     uuid: str
 
-    def __init__(self, name: str, uuid: str):
+    def __init__(self, name: str, uuid: str = None):
         super().__init__()
-        host = os.environ.get('HOST', 'learning-loop.ai')
+        host = os.environ.get('LOOP_HOST', None) or os.environ.get('HOST', 'learning-loop.ai')
         self.ws_url = f'ws{"s" if host != "backend" else ""}://' + host
-        self.organization = os.environ.get('ORGANIZATION', None)
-        self.project = os.environ.get('PROJECT', None)
+        self.organization = os.environ.get('LOOP_ORGANIZATION', None) or os.environ.get('ORGANIZATION', None)
+        self.project = os.environ.get('LOOP_PROJECT', None) or os.environ.get('PROJECT', None)
 
         self.name = name
-        self.uuid = uuid
+        self.uuid = self.read_or_create_uuid() if uuid is None else uuid
 
         self.sio_client = socketio.AsyncClient(
             reconnection_delay=0,
@@ -48,17 +49,35 @@ class Node(FastAPI):
 
         self.register_lifecycle_events()
 
+    def read_or_create_uuid(self) -> str:
+        if not os.path.exists('/data/uuid.txt'):
+            os.makedirs('/data', exist_ok=True)
+            uuid = str(uuid4())
+            with open('/data/uuid.txt', 'a+') as f:
+                f.write(uuid)
+        else:
+            with open('/data/uuid.txt', 'r') as f:
+                uuid = f.read()
+
+        return uuid
+
     def register_lifecycle_events(self):
         @self.on_event("startup")
         async def startup():
             logging.debug('received "startup" event')
-            await self.connect()
 
         @self.on_event("shutdown")
         async def shutdown():
             logging.debug('received "shutdown" event')
             await self.sio_client.disconnect()
 
+        @self.on_event("startup")
+        @repeat_every(seconds=10, raise_exceptions=False, wait_first=False)
+        async def ensure_connected() -> None:
+            if not self.sio_client.connected:
+                await self.connect()
+
+
     def reset(self):
         self.status = Status(id=self.uuid, name=self.name)
 
@@ -73,22 +92,14 @@ class Node(FastAPI):
 
         logging.info(f'connecting to Learning Loop at {self.ws_url}')
         try:
-            headers = await loop.get_headers()
+            headers = await asyncio.get_event_loop().run_in_executor(None, loop.get_headers)
             await self.sio_client.connect(f"{self.ws_url}", headers=headers, socketio_path="/ws/socket.io")
             logging.debug(f'my sid is {self.sio_client.sid}')
             logging.info('connected to Learning Loop')
         except socketio.exceptions.ConnectionError as e:
             logging.error(f'socket.io connection error to "{self.ws_url}"')
-            if not ('Already connected' in str(e) or 'Connection refused' in str(e) or 'Unexpected status code' in str(e)):
-                await asyncio.sleep(0.5)
-                await self.connect()
-        except ConnectionRefusedError or ClientConnectorError:
-            await asyncio.sleep(0.5)
-            await self.connect()
         except Exception:
-            logging.error(f'error while connecting to "{self.ws_url}"')
-            await asyncio.sleep(2)
-            await self.connect()
+            logging.exception(f'error while connecting to "{self.ws_url}"')
 
     async def update_state(self, state: State):
         self.status.state = state
@@ -110,6 +121,6 @@ class Node(FastAPI):
 
     @staticmethod
     def create_project_folder(context: Context) -> str:
-        project_folder = f'/data/{context.organization}/{context.project}'
+        project_folder = f'{context.base_folder}/{context.organization}/{context.project}'
         os.makedirs(project_folder, exist_ok=True)
         return project_folder
